==> ms_salesforce_api-2.15.0-py3-none-any.whl: ms_salesforce_api/salesforce/api/account/constants.py <==
DEFAULT_PROJECT_ACCOUNT_QUERY = """
SELECT
    Industry,
    Accelerator__c,
    Id,
    Name,
    Key_Account__c,
    MS_Customer_Account_Assigment_Group__c,
    MS_Customer_Tax_Category__c,
    MS_Customer_Tax_Classification__c,
    TXT_SAPId__c,
    ms_Business_Function__c,
    ms_TAX_id_Type__c,
    CurrencyISOCode,
    CreatedDate,
    Tier__c,
    PEC_Email__c,
    Phone,
    Fax,
    Website,
    CIF__c,
    BillingCountryCode,
    Business_Name__c,
    BillingAddress,
    BillingCity,
    BillingPostalCode,
    BillingStreet,
    LKP_MSCompanyInvoicing__r.PCK_Country__c,
    LKP_MSCompanyInvoicing__r.TXT_BusinessName__c,
    Payment_Terms__c,
    BillingStateCode,
    MAIL_Invoicing__c,
    Invoicing_Email__c,
    BQ_CustomerGroupId__c,
    BQ_CustomerSubgroupId__c,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.Name,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.DT_Start__c,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.DT_End__c,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.TXT_BQId__c,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.PCK_Type__c,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.MAIL_Supervisor__c,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.MAIL_Owner__c,
    LKP_CustomerSubgroup__r.Name,
    LKP_CustomerSubgroup__r.DT_Start__c,
    LKP_CustomerSubgroup__r.DT_End__c,
    LKP_CustomerSubgroup__r.TXT_BQId__c,
    LKP_CustomerSubgroup__r.MAIL_Owner__c,
    Owner.Email,
    Type
FROM
    Account
"""

DEFAULT_DELETE_ACCOUNTS_TABLE = "DELETE FROM Accounts WHERE true"

==> ms_salesforce_api-2.19.0-py3-none-any.whl: ms_salesforce_api/salesforce/api/account/constants.py <==
DEFAULT_PROJECT_ACCOUNT_QUERY = """
SELECT
    Industry,
    Accelerator__c,
    Id,
    Name,
    Key_Account__c,
    MS_Customer_Account_Assigment_Group__c,
    MS_Customer_Tax_Category__c,
    MS_Customer_Tax_Classification__c,
    TXT_SAPId__c,
    ms_Business_Function__c,
    ms_TAX_id_Type__c,
    CurrencyISOCode,
    CreatedDate,
    Tier__c,
    PEC_Email__c,
    Phone,
    Fax,
    Website,
    CIF__c,
    BillingCountryCode,
    Business_Name__c,
    BillingAddress,
    BillingCity,
    BillingPostalCode,
    BillingStreet,
    LKP_MSCompanyInvoicing__r.PCK_Prefix__c,
    LKP_MSCompanyInvoicing__r.TXT_BusinessName__c,
    Payment_Terms__c,
    BillingStateCode,
    MAIL_Invoicing__c,
    Invoicing_Email__c,
    BQ_CustomerGroupId__c,
    BQ_CustomerSubgroupId__c,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.Name,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.DT_Start__c,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.DT_End__c,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.TXT_BQId__c,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.PCK_Type__c,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.MAIL_Supervisor__c,
    LKP_CustomerSubgroup__r.LKP_CustomerGroup__r.MAIL_Owner__c,
    LKP_CustomerSubgroup__r.Name,
    LKP_CustomerSubgroup__r.DT_Start__c,
    LKP_CustomerSubgroup__r.DT_End__c,
    LKP_CustomerSubgroup__r.TXT_BQId__c,
    LKP_CustomerSubgroup__r.MAIL_Owner__c,
    Owner.Email,
    Type
FROM
    Account
"""

DEFAULT_DELETE_ACCOUNTS_TABLE = "DELETE FROM Accounts WHERE true"
